==> archibald-7.x-2.1.tar.gz: archibald/includes/languages/fr.php <==
<?php

/**
 * @file
 * List  ISO 639-1 language codes and its french names
 */
$languages = array(
  'aa' => 'Afar',
  'ab' => 'Abkhaze',
  'af' => 'Afrikaans',
  'am' => 'Amharique',
  'ar' => 'Arabe',
  'as' => 'Assamais',
  'ay' => 'Aymara',
  'az' => 'Azéri',
  'ba' => 'Bachkir',
  'be' => 'Biélorusse',
  'bg' => 'Bulgare',
  'bh' => 'Bihari',
  'bi' => 'Bichlamar',
  'bn' => 'Bengali',
  'bo' => 'Tibétain',
  'br' => 'Breton',
  'ca' => 'Catalan',
  'co' => 'Corse',
  'cs' => 'Tchèque',
  'cy' => 'Gallois',
  'da' => 'Danois',
  'de' => 'Allemand',
  'dz' => 'Dzongkha',
  'el' => 'Grec',
  'en' => 'Anglais',
  'eo' => 'Espéranto',
  'es' => 'Espagnol',
  'et' => 'Estonien',
  'eu' => 'Basque',
  'fa' => 'Persan',
  'fi' => 'Finnois',
  'fj' => 'Fidjien',
  'fo' => 'Féroïen',
  'fr' => 'Français',
  'fy' => 'Frison',
  'ga' => 'Irlandais',
  'gd' => 'Gaélique écossais',
  'gl' => 'Galicien',
  'gn' => 'Guarani',
  'gu' => 'Goudjrati',
  'ha' => 'Haoussa',
  'he' => 'Hébreu',
  'hi' => 'Hindi',
  'hr' => 'Croate',
  'hu' => 'Hongrois',
  'hy' => 'Arménien',
  'ia' => 'Interlingua',
  'id' => 'Indonésien',
  'ie' => 'Interlingue',
  'ik' => 'Inupiaq',
  'is' => 'Islandais',
  'it' => 'Italien',
  'iu' => 'Inuktitut',
  'iw' => '',
  'in' => '',
  'ja' => 'Japonais',
  'jw' => '',
  'ji' => '',
  'ka' => 'Géorgien',
  'kk' => 'Kazakh',
  'kl' => 'Groenlandais',
  'km' => 'Khmer',
  'kn' => 'Kannada',
  'ko' => 'Coréen',
  'ks' => 'Kashmiri',
  'ku' => 'Kurde',
  'ky' => 'Kirghize',
  'la' => 'Latin',
  'ln' => 'Lingala',
  'lo' => 'Lao',
  'lt' => 'Lituanien',
  'lv' => 'Letton',
  'mg' => 'Malgache',
  'mi' => 'Maori',
  'mk' => 'Macédonien',
  'ml' => 'Malayalam',
  'mn' => 'Mongol',
  'mo' => 'Moldave',
  'mr' => 'Marathe',
  'ms' => 'Malais',
  'mt' => 'Maltais',
  'my' => 'Birman',
  'na' => 'Nauruan',
  'ne' => 'Népalais',
  'nl' => 'Néerlandais',
  'no' => 'Norvégien',
  'oc' => 'Occitan (après 1500)',
  'om' => 'Galla',
  'or' => 'Oriya',
  'pa' => 'Pendjabi',
  'pl' => 'Polonais',
  'ps' => 'Pachto',
  'pt' => 'Portugais',
  'qu' => 'Quechua',
  'rm' => 'Rhéto-roman',
  'rm2907' => 'Rhaeto-Romance Puter',
  'rm2908' => 'Rhaeto-Romance Rumantsch grischun',
  'rm16068' => 'Rhaeto-Romance Surmiran',
  'rm16069' => 'Rhaeto-Romance Sursilvan',
  'rm13312' => 'Rhaeto-Romance Sutsilvan',
  'rm2906' => 'Rhaeto-Romance Vallader',
  'rn' => 'Roundi',
  'ro' => 'Roumain',
  'ru' => 'Russe',
  'rw' => 'Rwanda',
  'sa' => 'Sanskrit',
  'sd' => 'Sindhi',
  'sg' => 'Sango',
  'sh' => 'Serbo-croate',
  'si' => 'Singhalais',
  'sk' => 'Slovaque',
  'sl' => 'Slovène',
  'sm' => 'Samoan',
  'sn' => 'Shona',
  'so' => 'Somali',
  'sq' => 'Albanais',
  'sr' => 'Serbe',
  'ss' => 'Swati',
  'st' => 'Sotho du Sud',
  'su' => 'Soundanais',
  'sv' => 'Suédois',
  'sw' => 'Swahili',
  'ta' => 'Tamoul',
  'te' => 'Télougou',
  'tg' => 'Tadjik',
  'th' => 'Thaï',
  'ti' => 'Tigrigna',
  'tk' => 'Turkmène',
  'tl' => 'Tagalog',
  'tn' => 'Setswana',
  'to' => 'Tongan (Îles Tonga)',
  'tr' => 'Turc',
  'ts' => 'Tsonga',
  'tt' => 'Tatar',
  'tw' => 'Twi',
  'ug' => 'Ouïgour',
  'uk' => 'Ukrainien',
  'ur' => 'Ourdou',
  'uz' => 'Ouzbek',
  'vi' => 'Vietnamien',
  'vo' => 'Volapük',
  'wo' => 'Wolof',
  'xh' => 'Xhosa',
  'yi' => 'Yiddish',
  'yo' => 'Yoruba',
  'za' => 'Zhuang',
  'zh' => 'Chinois',
  'zu' => 'Zoulou',
);

==> archibald-7.x-2.9.tar.gz: archibald/includes/languages/fr.php <==
<?php

/**
 * @file
 * List  ISO 639-1 language codes and its french names
 */
$languages = array(
  'aa' => 'Afar',
  'ab' => 'Abkhaze',
  'af' => 'Afrikaans',
  'am' => 'Amharique',
  'ar' => 'Arabe',
  'as' => 'Assamais',
  'ay' => 'Aymara',
  'az' => 'Azéri',
  'ba' => 'Bachkir',
  'be' => 'Biélorusse',
  'bg' => 'Bulgare',
  'bh' => 'Bihari',
  'bi' => 'Bichlamar',
  'bn' => 'Bengali',
  'bo' => 'Tibétain',
  'br' => 'Breton',
  'ca' => 'Catalan',
  'co' => 'Corse',
  'cs' => 'Tchèque',
  'cy' => 'Gallois',
  'da' => 'Danois',
  'de' => 'Allemand',
  'dz' => 'Dzongkha',
  'el' => 'Grec',
  'en' => 'Anglais',
  'eo' => 'Espéranto',
  'es' => 'Espagnol',
  'et' => 'Estonien',
  'eu' => 'Basque',
  'fa' => 'Persan',
  'fi' => 'Finnois',
  'fj' => 'Fidjien',
  'fo' => 'Féroïen',
  'fr' => 'Français',
  'fy' => 'Frison',
  'ga' => 'Irlandais',
  'gd' => 'Gaélique écossais',
  'gl' => 'Galicien',
  'gn' => 'Guarani',
  'gu' => 'Goudjrati',
  'ha' => 'Haoussa',
  'he' => 'Hébreu',
  'hi' => 'Hindi',
  'hr' => 'Croate',
  'hu' => 'Hongrois',
  'hy' => 'Arménien',
  'ia' => 'Interlingua',
  'id' => 'Indonésien',
  'ie' => 'Interlingue',
  'ik' => 'Inupiaq',
  'is' => 'Islandais',
  'it' => 'Italien',
  'iu' => 'Inuktitut',
  'iw' => '',
  'in' => '',
  'ja' => 'Japonais',
  'jw' => '',
  'ji' => '',
  'ka' => 'Géorgien',
  'kk' => 'Kazakh',
  'kl' => 'Groenlandais',
  'km' => 'Khmer',
  'kn' => 'Kannada',
  'ko' => 'Coréen',
  'ks' => 'Kashmiri',
  'ku' => 'Kurde',
  'ky' => 'Kirghize',
  'la' => 'Latin',
  'ln' => 'Lingala',
  'lo' => 'Lao',
  'lt' => 'Lituanien',
  'lv' => 'Letton',
  'mg' => 'Malgache',
  'mi' => 'Maori',
  'mk' => 'Macédonien',
  'ml' => 'Malayalam',
  'mn' => 'Mongol',
  'mo' => 'Moldave',
  'mr' => 'Marathe',
  'ms' => 'Malais',
  'mt' => 'Maltais',
  'my' => 'Birman',
  'na' => 'Nauruan',
  'ne' => 'Népalais',
  'nl' => 'Néerlandais',
  'no' => 'Norvégien',
  'oc' => 'Occitan (après 1500)',
  'om' => 'Galla',
  'or' => 'Oriya',
  'pa' => 'Pendjabi',
  'pl' => 'Polonais',
  'ps' => 'Pachto',
  'pt' => 'Portugais',
  'qu' => 'Quechua',
  'rm' => 'Romanche',
  'rm2907' => 'Puter',
  'rm2908' => 'Rumantsch grischun',
  'rm16068' => 'Surmiran',
  'rm16069' => 'Sursilvan',
  'rm13312' => 'Sutsilvan',
  'rm2906' => 'Vallader',
  'rn' => 'Roundi',
  'ro' => 'Roumain',
  'ru' => 'Russe',
  'rw' => 'Rwanda',
  'sa' => 'Sanskrit',
  'sd' => 'Sindhi',
  'sg' => 'Sango',
  'sh' => 'Serbo-croate',
  'si' => 'Singhalais',
  'sk' => 'Slovaque',
  'sl' => 'Slovène',
  'sm' => 'Samoan',
  'sn' => 'Shona',
  'so' => 'Somali',
  'sq' => 'Albanais',
  'sr' => 'Serbe',
  'ss' => 'Swati',
  'st' => 'Sotho du Sud',
  'su' => 'Soundanais',
  'sv' => 'Suédois',
  'sw' => 'Swahili',
  'ta' => 'Tamoul',
  'te' => 'Télougou',
  'tg' => 'Tadjik',
  'th' => 'Thaï',
  'ti' => 'Tigrigna',
  'tk' => 'Turkmène',
  'tl' => 'Tagalog',
  'tn' => 'Setswana',
  'to' => 'Tongan (Îles Tonga)',
  'tr' => 'Turc',
  'ts' => 'Tsonga',
  'tt' => 'Tatar',
  'tw' => 'Twi',
  'ug' => 'Ouïgour',
  'uk' => 'Ukrainien',
  'ur' => 'Ourdou',
  'uz' => 'Ouzbek',
  'vi' => 'Vietnamien',
  'vo' => 'Volapük',
  'wo' => 'Wolof',
  'xh' => 'Xhosa',
  'yi' => 'Yiddish',
  'yo' => 'Yoruba',
  'za' => 'Zhuang',
  'zh' => 'Chinois',
  'zu' => 'Zoulou',
);
